@@ -50,9 +50,13 @@ R.Surv <- function(object, ...) {
     attr(ret, "prob") <- function(weights) {
         sf <- survival::survfit(object ~ 1, subset = weights > 0, weights = weights)
         function(y) {
-            s <- summary(sf, times = sort(y))$surv[order(y)]
+            uy <- sort(unique(y))
+            s <- summary(sf, times = uy)$surv
+            if (length(s) < length(uy))
+                s <- c(s, rep(0, length(uy) - length(s)))
             s[is.na(s)] <- 0
-            1 - s
+            p <- 1 - s
+            p[match(y, uy)]
         }
     }
     ret
